==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/fr-FR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Cet utilisateur peut se connecter',
    'activated_disabled_help_text' => 'Vous ne pouvez pas modifier l\'état de votre propre compte.',
    'assets_user'       => 'Actifs associés avec :name',
    'bulk_update_warn'	=> 'Vous êtes sur le point de modifier les propriétés de: user_count users. Veuillez noter que vous ne pouvez pas modifier vos propres attributs d\'utilisateur en utilisant ce formulaire et devez effectuer des modifications à votre propre utilisateur individuellement.',
    'bulk_update_help'	=> 'Ce formulaire vous permet de mettre à jour plusieurs utilisateurs à la fois. Remplissez uniquement les champs que vous devez modifier. Tous les champs laissés vides resteront inchangés.',
    'current_assets'    => 'Biens actuellement attribués à cet utilisateur',
    'clone'             => 'Cloner l\'utilisateur',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Modifier l\'utilisateur',
    'filetype_info'     => 'Types de fichier autorisés: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Historique pour :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Cliquez ici pour les restaurer.',
    'last_login'        => 'Dernière connexion',
    'ldap_config_text'  => 'Les paramètres de configuration LDAP se trouvent sous Admin > Réglages. La localisation sélectionnée (optionnelle) sera définie pour tous les utilisateurs importés.',
    'print_assigned'    => 'Imprimer tout ceux assignés',
    'email_assigned'    => 'Envoyer la liste des matériels assignés par email',
    'user_notified'     => 'Un mail récapitulatif de tous les articles associés à cet utilisateur lui a été envoyé.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Inclure cet utilisateur lors de l\'affectation automatique des licences éligibles',
    'auto_assign_help'  => 'Ignorer cet utilisateur dans l\'affectation automatique des licences',
    'software_user'     => 'Logiciels associés avec :name',
    'send_email_help'   => 'Vous devez fournir une adresse e-mail pour que cet utilisateur puisse recevoir ses identifiants. Les envois d\'identifiants par email ne peuvent être faits que lors de la création de l\'utilisateur. Les mots de passe sont stockés dans un hachage à sens unique et ne peuvent pas être récupérés une fois enregistrés.',
    'view_user'         => 'Voir l\'utilisateur :name',
    'usercsv'           => 'Fichier CSV',
    'two_factor_admin_optin_help' => 'Vos paramètres administratifs actuels permettent une application sélective de l\'authentification à deux facteurs.  ',
    'two_factor_enrolled' => 'Appareil relié à l\'authentification à deux facteurs (2FA) ',
    'two_factor_active'   => 'Authentification à deux facteurs (2FA) active ',
    'user_deactivated'  => 'L\'utilisateur ne peut pas se connecter',
    'user_activated'  => 'L\'utilisateur peut se connecter',
    'activation_status_warning' => 'Ne pas modifier le statut d\'activation',
    'group_memberships_helpblock' => 'Seuls les super-administrateurs peuvent modifier la liste de membres d\'un groupe.',
    'superadmin_permission_warning' => 'Seuls les super-administrateurs peuvent accorder un accès de super-administrateur à un utilisateur.',
    'admin_permission_warning' => 'Seuls les utilisateurs possédant des droits d\'administrateur ou mieux peuvent accorder un accès d\'administrateur à un utilisateur.',
    'remove_group_memberships' => 'Supprimer les appartenances de groupe',
    'warning_deletion_information' => 'Vous êtes sur le point d\'associer TOUS les articles des :count utilisateur(s) ci-dessous. Les noms des super-administrateurs sont indiqués en rouge.',
    'update_user_assets_status' => 'Appliquer ce status à tous les articles associés à ces utilisateurs',
    'checkin_user_properties' => 'Soumettre toutes les propriétés associées à ces utilisateurs',
    'remote_label'   => 'Il s\'agit d\'un utilisateur distant',
    'remote'   => 'Distant',
    'remote_help' => 'Cela peut être utile si vous avez besoin de filtrer les utilisateurs distants qui ne viennent pas ou peu dans vos locaux.',
    'not_remote_label' => 'Il ne s\'agit pas d\'un utilisateur distant',
    'vip_label' => 'Utilisateur VIP',
    'vip_help' => 'Cela peut être utile pour marquer des personnes importantes dans votre organisation si vous souhaitez les gérer de manière particulière.',
    'create_user' => 'Créer un utilisateur',
    'create_user_page_explanation' => 'Voici les informations de compte que vous utiliserez pour accéder au site la première fois.',
    'email_credentials' => 'Identifiants de l\'e-mail',
    'email_credentials_text' => 'Envoyer mes identifiants à l\'adresse e-mail ci-dessus',
    'next_save_user' => 'Étape suivante : Enregistrer l\'utilisateur',
    'all_assigned_list_generation' => 'Généré le :',
    'email_user_creds_on_create' => 'Envoyer à cet·te utilisateur·trice ses informations d\'identification par e-mail ?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/fr-FR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Cet utilisateur peut se connecter',
    'activated_disabled_help_text' => 'Vous ne pouvez pas modifier l\'état de votre propre compte.',
    'assets_user'       => 'Actifs associés avec :name',
    'bulk_update_warn'	=> 'Vous êtes sur le point de modifier les propriétés de: user_count users. Veuillez noter que vous ne pouvez pas modifier vos propres attributs d\'utilisateur en utilisant ce formulaire et devez effectuer des modifications à votre propre utilisateur individuellement.',
    'bulk_update_help'	=> 'Ce formulaire vous permet de mettre à jour plusieurs utilisateurs à la fois. Remplissez uniquement les champs que vous devez modifier. Tous les champs laissés vides resteront inchangés.',
    'current_assets'    => 'Biens actuellement attribués à cet utilisateur',
    'clone'             => 'Cloner l\'utilisateur',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Modifier l\'utilisateur',
    'filetype_info'     => 'Types de fichier autorisés: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Historique pour :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Cliquez ici pour les restaurer.',
    'last_login'        => 'Dernière connexion',
    'ldap_config_text'  => 'Les paramètres de configuration LDAP se trouvent sous Admin > Réglages. La localisation sélectionnée (optionnelle) sera définie pour tous les utilisateurs importés.',
    'print_assigned'    => 'Imprimer tout ceux assignés',
    'email_assigned'    => 'Envoyer la liste des matériels assignés par email',
    'user_notified'     => 'Un mail récapitulatif de tous les articles associés à cet utilisateur lui a été envoyé.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Inclure cet utilisateur lors de l\'affectation automatique des licences éligibles',
    'auto_assign_help'  => 'Ignorer cet utilisateur dans l\'affectation automatique des licences',
    'software_user'     => 'Logiciels associés avec :name',
    'view_user'         => 'Voir l\'utilisateur :name',
    'usercsv'           => 'Fichier CSV',
    'two_factor_admin_optin_help' => 'Vos paramètres administratifs actuels permettent une application sélective de l\'authentification à deux facteurs.  ',
    'two_factor_enrolled' => 'Appareil relié à l\'authentification à deux facteurs (2FA) ',
    'two_factor_active'   => 'Authentification à deux facteurs (2FA) active ',
    'user_deactivated'  => 'L\'utilisateur ne peut pas se connecter',
    'user_activated'  => 'L\'utilisateur peut se connecter',
    'activation_status_warning' => 'Ne pas modifier le statut d\'activation',
    'group_memberships_helpblock' => 'Seuls les super-administrateurs peuvent modifier la liste de membres d\'un groupe.',
    'superadmin_permission_warning' => 'Seuls les super-administrateurs peuvent accorder un accès de super-administrateur à un utilisateur.',
    'admin_permission_warning' => 'Seuls les utilisateurs possédant des droits d\'administrateur ou mieux peuvent accorder un accès d\'administrateur à un utilisateur.',
    'remove_group_memberships' => 'Supprimer les appartenances de groupe',
    'warning_deletion_information' => 'Vous êtes sur le point d\'associer TOUS les articles des :count utilisateur(s) ci-dessous. Les noms des super-administrateurs sont indiqués en rouge.',
    'update_user_assets_status' => 'Appliquer ce status à tous les articles associés à ces utilisateurs',
    'checkin_user_properties' => 'Soumettre toutes les propriétés associées à ces utilisateurs',
    'remote_label'   => 'Il s\'agit d\'un utilisateur distant',
    'remote'   => 'Distant',
    'remote_help' => 'Cela peut être utile si vous avez besoin de filtrer les utilisateurs distants qui ne viennent pas ou peu dans vos locaux.',
    'not_remote_label' => 'Il ne s\'agit pas d\'un utilisateur distant',
    'vip_label' => 'Utilisateur VIP',
    'vip_help' => 'Cela peut être utile pour marquer des personnes importantes dans votre organisation si vous souhaitez les gérer de manière particulière.',
    'create_user' => 'Créer un utilisateur',
    'create_user_page_explanation' => 'Voici les informations de compte que vous utiliserez pour accéder au site la première fois.',
    'email_credentials' => 'Identifiants de l\'e-mail',
    'email_credentials_text' => 'Envoyer mes identifiants à l\'adresse e-mail ci-dessus',
    'next_save_user' => 'Étape suivante : Enregistrer l\'utilisateur',
    'all_assigned_list_generation' => 'Généré le :',
    'email_user_creds_on_create' => 'Envoyer à cet·te utilisateur·trice ses informations d\'identification par e-mail ?',
    'department_manager' => 'Department Manager',
];
